import EntityTab from 'atoms/EntityTab';
import Tab from 'bootstrap3-components/Tab';
import { getMenuTemplateList } from 'constant/menu_template';
import CloudServiceProvider from 'model/CloudServiceProvider';
import React, { useEffect, useState } from 'react';
import { getEntityListViewUrl } from 'service/utility';

/**
 * Tab elements for entity view.
 *
 * @param tabColumnList List of tab columns.
 */
const EntityTabsImpl = ({ tabColumnList }: {
  tabColumnList: {
    isActive: boolean,
    location: string,
    children: React.ReactNode
  }[]
}) => {

  return <Tab.Group>
    {
      tabColumnList.map((tabColumn, index) => {
        return <EntityTab
          key={index}
          isActive={tabColumn.isActive}
          location={tabColumn.location}
          children={tabColumn.children}
        />;
      })
    }
  </Tab.Group>;

}

/**
 * Tab elements for entity view.
 *
 * @param menuType Cloud service provider.
 * @param menuName Active tab name.
 */
const EntityTabs = ({ menuType, menuName, cloudContext }: {
  menuType: CloudServiceProvider,
  menuName: string,
  cloudContext?: string
}) => {

  const [tabColumnList, setTabColumnList] = useState<{
    isActive: boolean;
    location: string;
    children: string;
  }[]>([]);

  useEffect(() => {
    setTabColumnList(
      getMenuTemplateList(menuType)
        .map((menu) => {
          return {
            isActive: menu.labelName === menuName,
            location: getEntityListViewUrl(menu, cloudContext),
            children: menu.labelName,
          };
        })
    );
  }, [menuType, menuName, cloudContext]);

  return <EntityTabsImpl tabColumnList={tabColumnList} />;

}

export default EntityTabs;
