import Button from 'bootstrap3-components/Button';
import Form from 'bootstrap3-components/Form';
import GlyphIcon from 'bootstrap3-components/GlyphIcon';
import Table from 'bootstrap3-components/Table';
import { useTranslation } from 'react-i18next';

/**
 * Block of key-value input view.
 *
 * @param 
 */
const MultiNumberInputBlock = ({ label, value, setValue, required, readOnly }: {
  label: string,
  value: number[],
  setValue: (n: number[]) => void,
  required: boolean,
  readOnly: boolean,
}) => {

  const { t } = useTranslation();

  if (!Array.isArray(value)) {
    return <></>;
  }

  return <Form.Group>
    <Form.Label className={required ? 'form-required' : ''}>{label}</Form.Label>
    <Table striped>
      <tbody>
        {
          value.map((v, index) => {
            return <tr key={index}>
              <td>
                <input className="form-text form-control" type="number" value={v} onChange={(e) => {
                  const newValue: number[] = JSON.parse(JSON.stringify(value));
                  newValue[index] = parseInt(e.currentTarget.value, 10);
                  setValue(newValue);
                }} readOnly={readOnly} />
              </td>
              <td>
                <Button.Group>
                  <Button onClick={() => {
                    const newValue: number[] = [];
                    for (let index2 = 0; index2 < value.length; index2 += 1) {
                      newValue.push(value[index2]);
                      if (index2 === index) {
                        newValue.push(10);
                      }
                    }
                    setValue(newValue);
                  }} disabled={readOnly}>＋</Button>
                  <Button onClick={() => {
                    if (index === 0) {
                      return;
                    }
                    const newValue: number[] = JSON.parse(JSON.stringify(value));
                    newValue[index] = value[index - 1];
                    newValue[index - 1] = value[index];
                    setValue(newValue);
                  }} disabled={readOnly}>↑</Button>
                  <Button onClick={() => {
                    if (index === value.length - 1) {
                      return;
                    }
                    const newValue: number[] = JSON.parse(JSON.stringify(value));
                    newValue[index] = value[index + 1];
                    newValue[index + 1] = value[index];
                    setValue(newValue);
                  }} disabled={readOnly}>↓</Button>
                  <Button className="icon-before btn-danger" onClick={() => {
                    if (value.length === 1) {
                      return;
                    }
                    const newValue: number[] = [];
                    for (let index2 = 0; index2 < value.length; index2 += 1) {
                      if (index2 !== index) {
                        newValue.push(value[index2]);
                      }
                    }
                    setValue(newValue);
                  }} disabled={readOnly}>
                    <GlyphIcon iconName="delete" />{' ' + t('Delete')}
                  </Button>
                </Button.Group>
              </td>
            </tr>;
          })
        }
      </tbody>
    </Table>
  </Form.Group>;

}

export default MultiNumberInputBlock;
