import Form from 'bootstrap3-components/Form';

/**
 * Block of key-value input view.
 *
 * @param 
 */
const RadioSelectBlock = ({ label, value, setValue, valueList, orientation, required, readOnly }: {
  label: string,
  value: string,
  setValue: (s: string) => void,
  valueList: { labelName: string, name: string }[],
  orientation: 'horizontal' | 'vertical',
  required: boolean,
  readOnly: boolean,
}) => {

  if (orientation === 'vertical') {
    return <Form.Group>
      <Form.Group>
        <Form.Label className={required ? 'form-required' : ''}>{label}</Form.Label>
      </Form.Group>
      <div>
        {
          valueList.map((valueRecord) => {
            return <div className="radio" key={valueRecord.name}>
              <Form.Label className="option">
                <input className="form-radio" type="radio"
                  checked={value === valueRecord.name}
                  onChange={() => {
                    setValue(valueRecord.name);
                  }} readOnly={readOnly} />
                {valueRecord.labelName}
              </Form.Label>
            </div>;
          })
        }
      </div>
    </Form.Group>;
  } else {
    return <div className="container-inline">
      <b className={required ? 'form-required' : ''}>{`${label}: `}</b>
      <div>
        {
          valueList.map((valueRecord) => {
            return <div className="radio" style={{marginRight: 5}} key={valueRecord.name}>
              <Form.Label className="option">
                <input className="form-radio" type="radio"
                  checked={value === valueRecord.name}
                  onChange={() => {
                    setValue(valueRecord.name);
                  }} readOnly={readOnly} />
                {valueRecord.labelName}
              </Form.Label>
            </div>;
          })
        }
      </div>
    </div>;
  }
}

export default RadioSelectBlock;
