import Col from 'bootstrap3-components/Col';
import FluidContainer from 'bootstrap3-components/FluidContainer';
import Form from 'bootstrap3-components/Form';
import Row from 'bootstrap3-components/Row';
import PageSelector from 'molecules/PageSelector';
import ResourceCountLabel from 'molecules/ResourceCountLabel';
import MenuBar from 'organisms/MenuBar';
import ResourceStoreTable from 'organisms/ResourceStoreTable';
import { useState } from 'react';

/**
 * The Page of Cloud Resource Store.
 *
 * @param bundleId The bundle ID, such as k8s_cost_store.
 */
const CloudResourceStorePage = ({ bundleId }: {
  bundleId: string
}) => {
  const [itemCount, setItemCount] = useState(0);
  const [pageIndex, setPageIndex] = useState(0);

  return <>
    <MenuBar cloudServiceProvider="k8s" cloudContext={undefined} />
    <FluidContainer className="px-0">
      <Row className="mx-0">
        <Col>
          <Form>
            <Form.Group style={{ marginTop: '2rem' }}>
              <ResourceCountLabel
                bundleId={bundleId}
                itemCount={itemCount}
                setItemCount={setItemCount} />
            </Form.Group>
          </Form>
        </Col>
      </Row>
    </FluidContainer>
    <PageSelector
      pageIndex={pageIndex}
      setPageIndex={setPageIndex}
      itemCount={itemCount} />
    <FluidContainer className="px-0">
      <Row className="mx-0">
        <Col>
          <Form>
            <ResourceStoreTable bundleId={bundleId} pageIndex={pageIndex} />
          </Form>
        </Col>
      </Row>
    </FluidContainer>
    <PageSelector
      pageIndex={pageIndex}
      setPageIndex={setPageIndex}
      itemCount={itemCount} />
  </>;
}

export default CloudResourceStorePage;
