Feature: Create resources for K8s as "Authenticated User"
  As a user
  I need to create and delete a network policy

  @api @javascript
  Scenario: Create a network policy
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/network_policy/add"
    And I should see the heading "Add Network policy"
    And I select "{{ namespace }}" from "Namespace"
    And I fill in "Detail" with:
    """
    apiVersion: networking.k8s.io/v1
    kind: NetworkPolicy
    metadata:
      name: {{ network_policy_name }}
      namespace: {{ namespace }}
    spec:
      podSelector:
        matchLabels:
          role: db
      policyTypes:
        - Ingress
        - Egress
      ingress:
        - from:
            - ipBlock:
                cidr: 172.17.0.0/16
                except:
                  - 172.17.1.0/24
            - namespaceSelector:
                matchLabels:
                  project: myproject
            - podSelector:
                matchLabels:
                  role: frontend
          ports:
            - protocol: TCP
              port: 6379
      egress:
        - to:
           - ipBlock:
                cidr: 10.0.0.0/24
          ports:
            - protocol: TCP
              port: 5978
    """
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/k8s/{{ cloud_context }}/network_policy"
    And I should see "has been created"
    And I should see "{{ network_policy_name }}" in the "{{ namespace }}" row

  @api @javascript
  Scenario: Delete the network policy
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/network_policy"
    And I click "Refresh"
    And I wait {{ wait }} milliseconds
    And I should see the link "{{ network_policy_name }}"
    And I click "{{ network_policy_name }}"
    And the url should match "/k8s/{{ cloud_context }}/network_policy/"
    And I click "Delete" in the "actions"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then I should be on "/clouds/k8s/{{ cloud_context }}/network_policy"
    And I should see "has been deleted"
    And I click "Refresh"
    And I should not see the link "{{ network_policy_name }}"
