Feature: Create resources for K8s as "Authenticated User"
  As a user
  I need to create and delete a DaemonSet

  @api @javascript
  Scenario: Create a daemon set
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/daemon_set/add"
    And I should see the heading "Add DaemonSet"
    And I select "{{ namespace }}" from "Namespace"
    And I fill in "Detail" with:
    """
    apiVersion: apps/v1
    kind: DaemonSet
    metadata:
      name: {{ daemonset_name }}
      labels:
        k8s-app: {{ app_name }}
    spec:
      selector:
        matchLabels:
          name: {{ app_name }}
      template:
        metadata:
          labels:
            name: {{ app_name }}
        spec:
          tolerations:
          # these tolerations are to have the daemonset runnable on control plane nodes
          # remove them if your control plane nodes should not run pods
          - key: node-role.kubernetes.io/control-plane
            operator: Exists
            effect: NoSchedule
          - key: node-role.kubernetes.io/master
            operator: Exists
            effect: NoSchedule
          containers:
          - name: {{ container_name }}
            image: {{ image_version }}
            resources:
              limits:
                cpu: {{ max_cpu }}
              requests:
                cpu: {{ min_cpu }}
            volumeMounts:
            - name: www
              mountPath: {{ volume_mount_path }}
          terminationGracePeriodSeconds: 30
          volumes:
          - name: www
            hostPath:
              path: {{ volume_local_path }}
    """
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/k8s/{{ cloud_context }}/daemon_set"
    And I should see "has been created"
    And I should see "{{ daemonset_name }}" in the "{{ namespace }}" row

  @api @javascript
  Scenario: Delete the DaemonSet
    Given I am logged in as user "{{ user_name }}"
    When I visit "/clouds/k8s/{{ cloud_context }}/daemon_set"
    And I click "Refresh"
    And I wait {{ wait }} milliseconds
    And I should see the link "{{ daemonset_name }}"
    And I click "{{ daemonset_name }}"
    And the url should match "/k8s/{{ cloud_context }}/daemon_set/"
    And I click "Delete" in the "actions"
    And the url should match "/delete"
    And I press "Delete"
    And I wait for AJAX to finish
    Then I should be on "/clouds/k8s/{{ cloud_context }}/daemon_set"
    And I should see "has been deleted"
    And I click "Refresh"
    And I should not see the link "{{ daemonset_name }}"
