<?php

namespace Drupal\openstack\Service;

use Drupal\aws_cloud\Entity\Ec2\ImageInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides OpenStackOperationsService interface.
 */
interface OpenStackOperationsServiceInterface {

  /**
   * Create an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function createOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Edit an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function editOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

  /**
   * Delete an OpenStack image.
   *
   * @param \Drupal\aws_cloud\Entity\Ec2\ImageInterface $entity
   *   The OpenStack image entity.
   * @param array $form
   *   Array of form object.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return bool
   *   TRUE when the process succeeds.
   */
  public function deleteOpenStackImage(ImageInterface $entity, array &$form, FormStateInterface $form_state): bool;

}
